@@ -19,24 +19,14 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorGeneralConfig, "akregator_config_general.json")
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMAkregatorGeneralConfig::KCMAkregatorGeneralConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , m_widget(new QWidget(this))
-#else
-KCMAkregatorGeneralConfig::KCMAkregatorGeneralConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMAkregatorGeneralConfig::KCMAkregatorGeneralConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , m_widget(new QWidget(widget()))
-#endif
 {
     Ui::SettingsGeneral ui;
     ui.setupUi(m_widget);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto layout = new QVBoxLayout(this);
-#else
     auto layout = new QVBoxLayout(widget());
-#endif
     layout->addWidget(m_widget);
 
     ui.kcfg_AutoFetchInterval->setSuffix(ki18np(" minute", " minutes"));
@@ -47,3 +37,5 @@ KCMAkregatorGeneralConfig::KCMAkregatorGeneralConfig(QObject *parent, const KPlu
 }
 
 #include "akregator_config_general.moc"
+
+#include "moc_akregator_config_general.cpp"
