@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,8 @@ public:
     [[nodiscard]] QString formatFeed(Akregator::Feed *feed);
 
 private:
-    void addStandardObject(QVariantHash &grantleeObject);
+    void addStandardObject(QVariantHash &grantleeObject) const;
+    [[nodiscard]] QString sidebarCss() const;
     [[nodiscard]] int pointsToPixel(int pointSize) const;
     const QString mHtmlArticleFileName;
     const QString mDirectionString;
